@@ -1,26 +1,15 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 Reginald Stadlbauer (reggie@kde.org)
-    (C) 1997, 1998 Stephan Kulow (coolo@kde.org)
-    (C) 1997, 1998 Sven Radej (radej@kde.org)
-    (C) 1997, 1998 Mark Donohoe (donohoe@kde.org)
-    (C) 1997, 1998 Matthias Ettrich (ettrich@kde.org)
-    (C) 1999, 2000 Kurt Granroth (granroth@kde.org)
-    (C) 2005-2006 Hamish Rodda (rodda@kde.org)
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Reginald Stadlbauer <reggie@kde.org>
+    SPDX-FileCopyrightText: 1997, 1998 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 1997, 1998 Sven Radej <radej@kde.org>
+    SPDX-FileCopyrightText: 1997, 1998 Mark Donohoe <donohoe@kde.org>
+    SPDX-FileCopyrightText: 1997, 1998 Matthias Ettrich <ettrich@kde.org>
+    SPDX-FileCopyrightText: 1999, 2000 Kurt Granroth <granroth@kde.org>
+    SPDX-FileCopyrightText: 2005-2006 Hamish Rodda <rodda@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
-    */
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #ifndef KTOOLBAR_H
 #define KTOOLBAR_H
@@ -28,6 +17,7 @@
 #include <kxmlgui_export.h>
 
 #include <QToolBar>
+#include <memory>
 
 class QDomElement;
 
@@ -61,11 +51,18 @@ class KXMLGUIClient;
    options_show_toolbar=false
    @endverbatim
  *
- * @note If you can't depend on KXmlGui but you want to integrate with KDE, you can use QToolBar with:
- *    Set ToolButtonStyle to Qt::ToolButtonFollowStyle, this will make QToolBar use the settings for "Main Toolbar"
- *    Additionally set QToolBar::setProperty("otherToolbar", true) to use settings for "Other toolbars"
- *    Settings from "Other toolbars" will only work on widget styles derived from KStyle
- * @author Reginald Stadlbauer <reggie@kde.org>, Stephan Kulow <coolo@kde.org>, Sven Radej <radej@kde.org>, Hamish Rodda <rodda@kde.org>.
+ * If you can't depend on KXmlGui but still want to integrate better with KDE,
+ * you can use QToolBar and:
+ * - Set ToolButtonStyle to Qt::ToolButtonFollowStyle, this will make QToolBar
+ *   use the settings for "Main Toolbar"
+ * - Additionally set QToolBar::setProperty("otherToolbar", true) to use settings
+ *   for "Other toolbars"; settings from "Other toolbars" will only work on widget
+ *   styles derived from KStyle
+ *
+ * @author Reginald Stadlbauer <reggie@kde.org>
+ * @author Stephan Kulow <coolo@kde.org>
+ * @author Sven Radej <radej@kde.org>
+ * @author Hamish Rodda <rodda@kde.org>
  */
 class KXMLGUI_EXPORT KToolBar : public QToolBar
 {
@@ -119,13 +116,17 @@ public:
      * @param isMainToolBar  True for the "main toolbar", false for other toolbars. Different settings apply.
      * @param readConfig  whether to apply the configuration (global and application-specific)
      */
-    KToolBar(const QString &objectName, QMainWindow *parentWindow, Qt::ToolBarArea area, bool newLine = false,
-             bool isMainToolBar = false, bool readConfig = true); // KDE5: remove, I don't think anyone is using this.
+    KToolBar(const QString &objectName,
+             QMainWindow *parentWindow,
+             Qt::ToolBarArea area,
+             bool newLine = false,
+             bool isMainToolBar = false,
+             bool readConfig = true); // KDE5: remove, I don't think anyone is using this.
 
     /**
      * Destroys the toolbar.
      */
-    virtual ~KToolBar();
+    ~KToolBar() override;
 
     /**
      * Returns the main window that this toolbar is docked with.
@@ -258,23 +259,12 @@ protected:
     void mouseReleaseEvent(QMouseEvent *) override;
 
 private:
-    class Private;
-    Private *const d;
+    friend class KToolBarPrivate;
+    std::unique_ptr<class KToolBarPrivate> const d;
 
     Q_PRIVATE_SLOT(d, void slotAppearanceChanged())
-    Q_PRIVATE_SLOT(d, void slotContextAboutToShow())
-    Q_PRIVATE_SLOT(d, void slotContextAboutToHide())
-    Q_PRIVATE_SLOT(d, void slotContextLeft())
     Q_PRIVATE_SLOT(d, void slotContextRight())
-    Q_PRIVATE_SLOT(d, void slotContextShowText())
-    Q_PRIVATE_SLOT(d, void slotContextTop())
-    Q_PRIVATE_SLOT(d, void slotContextBottom())
-    Q_PRIVATE_SLOT(d, void slotContextIcons())
-    Q_PRIVATE_SLOT(d, void slotContextText())
     Q_PRIVATE_SLOT(d, void slotContextTextRight())
-    Q_PRIVATE_SLOT(d, void slotContextTextUnder())
-    Q_PRIVATE_SLOT(d, void slotContextIconSize())
-    Q_PRIVATE_SLOT(d, void slotLockToolBars(bool))
 };
 
 #endif
